<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Vključen režim letalne ploščice</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Vključen režim letalne ploščice je zapuščen</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Onemogoči</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Omogoči</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Režim letalne ploščice</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Nastavitve režima letalne ploščice</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Režim letalne ploščice</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Moji urejali</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth nastavitve</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Izklopi</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Vklopi</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth nastavitve</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 je povezan</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Povezovanje...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Izklopljen</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Povezan %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ni povezan</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Iskalnik</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Jasenost</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Nastavitve zaslonja</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Nastavitve zaslonja</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Jasenost</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Ned</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Pon</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Sre</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Čet</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Pet</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Sob</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Dodaj razpored tipk</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum in čas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 urni čas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 urni čas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Nastavitve časa</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Odpri kalendar</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Ponedeljek</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Torek</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Sreda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Četrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Petek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Nedelja</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>ponedeljek</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>ponedeljek</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>toreg</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>sreda</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>četrtek</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>petek</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>sobota</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Drugi urejali</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Režim DND</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Nastavitve DND načina</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Dezaktiveni</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Omogoči</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>DND način omogočen</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>DND način dezaktiven</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Način DND</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Ugodnost oči</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Ugodnost oči omogočena</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Ugodnost oči dezaktivena</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Nastavitve zaslove</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Ugodnost oči</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tematika</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Vključeno</translation>
    </message>
    <message>
        <source>Off</source>
        <translation> izključeno</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Svetlo</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Temno</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Samodejno</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Dezaktiveni upravljanje zgodnosti oči</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Omogoči upravljanje zgodnosti oči</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Nastavitve zaslove</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Tematika: Svetlo</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Tematika: Temno</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Tematika: Samodejno</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Zračna učinka</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Svetlo</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Temno</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Samodejno</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Temat</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Ni sporočil</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Nastavitve opoznavanj</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Opoznavanja</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Izključi način NEDELJ</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Vključi način NEDELJ</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Opoznavanje</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Na plošči</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Visoka vire</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Prilagodljivo</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Vire za učenje</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Prilagodljiva vire</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Vire</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Nastavitve energijske porabe</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Zmogljivost %1 za %2 min</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Zmogljivost %1 za %2 ur in %3 min</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Polnjenje %1 bo končano čez %2 min</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Polnjenje %1 bo končano čez %2 ur in %3 min</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Zmogljivost %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Polnim %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Zmogljvost %1 ..</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Zmogljivost %1 - polno</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Vire %1, ne naredi</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Akumulator</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Naredi, izračunaj ocenjen čas nareditve</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Izračunaj preostal čas uporabe</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>Preostal %1 min</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 ur %2 min preostal</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Ne naredi</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Potovan</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Naredi, %1 min do konca</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>%1 ur %2 min do konca nareditve</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Vire %1, %2 ur preostalih</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 ur preostega</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Vzdrževanje %1, %2 ur preostalo do celotnega vzdrževanja</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Vzdrževanje, %1 ur preostalo do celotnega vzdrževanja</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Muzika</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznano</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Zaustavitev sistema</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mirovanje</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Spanje</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zakleni</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Izpis</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavitve energijske porabe</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovni zagon</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Posodobitev in izklopi</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Posodobitev in ponovno zagon</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Izklopi</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Premakni uporabnika</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Danes</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Miesiški</translation>
    </message>
    <message>
        <source>y</source>
        <translation>leto</translation>
    </message>
    <message>
        <source>m</source>
        <translation>mesec</translation>
    </message>
    <message>
        <source>d</source>
        <translation>dan</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jan</source>
        <translation>Jan</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Feb</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Mar</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Apr</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Maj</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Jun</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Jul</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Avg</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Sep</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Okt</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Nov</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Dec</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Odpri kalkulator</translation>
    </message>
    <message>
        <source>monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>tuesday</source>
        <translation>tore</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>sreda</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>čtvrtek</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>petek</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sobota</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>nedelja</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Glasnost</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Izhod</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Nastavitve zvočnega uređaja</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zvok</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Prekliči zapiranje</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Nastavitve zvočnega uređaja</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Ni uređajev za izhod</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Zvok %1</translation>
    </message>
</context>
</TS>